@@ -10,10 +10,11 @@
 #pragma once
 
 #include <deque>
-#include <openrct2/core/String.hpp>
+#include <openrct2/core/StringTypes.h>
 #include <openrct2/interface/InteractiveConsole.h>
 #include <openrct2/localisation/FormatCodes.h>
 #include <openrct2/world/Location.hpp>
+#include <vector>
 
 namespace OpenRCT2::Ui
 {
