@@ -20,7 +20,6 @@
 #include <openrct2/object/TerrainSurfaceObject.h>
 #include <openrct2/sprites.h>
 #include <openrct2/world/Map.h>
-#include <openrct2/world/Surface.h>
 
 using namespace OpenRCT2;
 using namespace OpenRCT2::Ui::Windows;
@@ -61,7 +60,7 @@ void LandTool::ShowSurfaceStyleDropdown(WindowBase* w, Widget* widget, ObjectEnt
     auto itemIndex = 0;
     for (size_t i = 0; i < kMaxTerrainSurfaceObjects; i++)
     {
-        const auto surfaceObj = static_cast<TerrainSurfaceObject*>(objManager.GetLoadedObject(ObjectType::TerrainSurface, i));
+        const auto surfaceObj = objManager.GetLoadedObject<TerrainSurfaceObject>(i);
         // If fallback images are loaded, the RCT1 styles will just look like copies of already existing styles, so hide them.
         if (surfaceObj != nullptr && !surfaceObj->UsesFallbackImages())
         {
@@ -93,7 +92,7 @@ ObjectEntryIndex LandTool::GetSurfaceStyleFromDropdownIndex(size_t index)
     auto itemIndex = 0U;
     for (size_t i = 0; i < kMaxTerrainSurfaceObjects; i++)
     {
-        const auto surfaceObj = static_cast<TerrainSurfaceObject*>(objManager.GetLoadedObject(ObjectType::TerrainSurface, i));
+        const auto surfaceObj = objManager.GetLoadedObject<TerrainSurfaceObject>(i);
         // If fallback images are loaded, the RCT1 styles will just look like copies of already existing styles, so hide them.
         if (surfaceObj != nullptr && !surfaceObj->UsesFallbackImages())
         {
@@ -115,7 +114,7 @@ void LandTool::ShowEdgeStyleDropdown(WindowBase* w, Widget* widget, ObjectEntryI
     auto itemIndex = 0;
     for (size_t i = 0; i < kMaxTerrainEdgeObjects; i++)
     {
-        const auto edgeObj = static_cast<TerrainEdgeObject*>(objManager.GetLoadedObject(ObjectType::TerrainEdge, i));
+        const auto edgeObj = objManager.GetLoadedObject<TerrainEdgeObject>(i);
         // If fallback images are loaded, the RCT1 styles will just look like copies of already existing styles, so hide them.
         if (edgeObj != nullptr && !edgeObj->UsesFallbackImages())
         {
@@ -144,7 +143,7 @@ ObjectEntryIndex LandTool::GetEdgeStyleFromDropdownIndex(size_t index)
     auto itemIndex = 0U;
     for (size_t i = 0; i < kMaxTerrainEdgeObjects; i++)
     {
-        const auto edgeObj = static_cast<TerrainEdgeObject*>(objManager.GetLoadedObject(ObjectType::TerrainEdge, i));
+        const auto edgeObj = objManager.GetLoadedObject<TerrainEdgeObject>(i);
         // If fallback images are loaded, the RCT1 styles will just look like copies of already existing styles, so hide them.
         if (edgeObj != nullptr && !edgeObj->UsesFallbackImages())
         {
