@@ -25,61 +25,62 @@
 
 namespace OpenRCT2::Ui::Windows
 {
-    // clang-format off
-enum WindowPlayerPage {
-    WINDOW_PLAYER_PAGE_OVERVIEW,
-    WINDOW_PLAYER_PAGE_STATISTICS,
-};
+    enum WindowPlayerPage
+    {
+        WINDOW_PLAYER_PAGE_OVERVIEW,
+        WINDOW_PLAYER_PAGE_STATISTICS,
+    };
 
 #pragma region Widgets
 
-enum WindowPlayerWidgetIdx {
-    WIDX_BACKGROUND,
-    WIDX_TITLE,
-    WIDX_CLOSE,
-    WIDX_PAGE_BACKGROUND,
-    WIDX_TAB_1,
-    WIDX_TAB_2,
+    // clang-format off
+    enum WindowPlayerWidgetIdx
+    {
+        WIDX_BACKGROUND,
+        WIDX_TITLE,
+        WIDX_CLOSE,
+        WIDX_PAGE_BACKGROUND,
+        WIDX_TAB_1,
+        WIDX_TAB_2,
 
-    WIDX_GROUP = 6,
-    WIDX_GROUP_DROPDOWN,
-    WIDX_LOCATE,
-    WIDX_KICK,
-    WIDX_VIEWPORT,
-};
+        WIDX_GROUP = 6,
+        WIDX_GROUP_DROPDOWN,
+        WIDX_LOCATE,
+        WIDX_KICK,
+        WIDX_VIEWPORT,
+    };
 
-#define WINDOW_PLAYER_COMMON_WIDGETS                                                                                                    \
-    MakeWidget({  0,  0}, {192, 157}, WindowWidgetType::Frame,    WindowColour::Primary                                     ), /* Panel / Background */ \
-    MakeWidget({  1,  1}, {190,  14}, WindowWidgetType::Caption,  WindowColour::Primary  , STR_STRING,  STR_WINDOW_TITLE_TIP), /* Title              */ \
-    MakeWidget({179,  2}, { 11,  12}, WindowWidgetType::CloseBox, WindowColour::Primary  , STR_CLOSE_X, STR_CLOSE_WINDOW_TIP), /* Close x button     */ \
-    MakeWidget({  0, 43}, {192, 114}, WindowWidgetType::Resize,   WindowColour::Secondary                                   ), /* Resize             */ \
-    MakeTab   ({  3, 17}                                                                                      ), /* Tab 1              */ \
-    MakeTab   ({ 34, 17}                                                                                      )  /* Tab 2              */
+    #define WINDOW_PLAYER_COMMON_WIDGETS                                                                                              \
+        MakeWidget({ 0, 0 }, { 192, 157 }, WindowWidgetType::Frame, WindowColour::Primary),                                           \
+        MakeWidget({ 1, 1 }, { 190, 14 }, WindowWidgetType::Caption, WindowColour::Primary, STR_STRING, STR_WINDOW_TITLE_TIP),    \
+        MakeWidget({ 179, 2 }, { 11, 12 }, WindowWidgetType::CloseBox, WindowColour::Primary, STR_CLOSE_X, STR_CLOSE_WINDOW_TIP), \
+        MakeWidget({ 0, 43 }, { 192, 114 }, WindowWidgetType::Resize, WindowColour::Secondary),                                   \
+        MakeTab({ 3, 17 }),                                                                                                       \
+        MakeTab({ 34, 17 })
 
-static Widget window_player_overview_widgets[] = {
-    WINDOW_PLAYER_COMMON_WIDGETS,
-    MakeWidget({  3, 46}, {175, 12}, WindowWidgetType::DropdownMenu, WindowColour::Secondary                                           ), // Permission group
-    MakeWidget({167, 47}, { 11, 10}, WindowWidgetType::Button,   WindowColour::Secondary, STR_DROPDOWN_GLYPH                       ),
-    MakeWidget({179, 45}, { 12, 24}, WindowWidgetType::FlatBtn,  WindowColour::Secondary, ImageId(SPR_LOCATE),         STR_LOCATE_PLAYER_TIP), // Locate button
-    MakeWidget({179, 69}, { 12, 24}, WindowWidgetType::FlatBtn,  WindowColour::Secondary, ImageId(SPR_DEMOLISH),       STR_KICK_PLAYER_TIP  ), // Kick button
-    MakeWidget({  3, 60}, {175, 61}, WindowWidgetType::Viewport, WindowColour::Secondary                                           ), // Viewport
-    kWidgetsEnd,
-};
+    static Widget window_player_overview_widgets[] = {
+        WINDOW_PLAYER_COMMON_WIDGETS,
+        MakeWidget({  3, 46}, {175, 12}, WindowWidgetType::DropdownMenu, WindowColour::Secondary                                           ), // Permission group
+        MakeWidget({167, 47}, { 11, 10}, WindowWidgetType::Button,   WindowColour::Secondary, STR_DROPDOWN_GLYPH                       ),
+        MakeWidget({179, 45}, { 12, 24}, WindowWidgetType::FlatBtn,  WindowColour::Secondary, ImageId(SPR_LOCATE),         STR_LOCATE_PLAYER_TIP), // Locate button
+        MakeWidget({179, 69}, { 12, 24}, WindowWidgetType::FlatBtn,  WindowColour::Secondary, ImageId(SPR_DEMOLISH),       STR_KICK_PLAYER_TIP  ), // Kick button
+        MakeWidget({  3, 60}, {175, 61}, WindowWidgetType::Viewport, WindowColour::Secondary                                           ), // Viewport
+        kWidgetsEnd,
+    };
 
-static Widget window_player_statistics_widgets[] = {
-    WINDOW_PLAYER_COMMON_WIDGETS,
-    kWidgetsEnd,
-};
+    static Widget window_player_statistics_widgets[] = {
+        WINDOW_PLAYER_COMMON_WIDGETS,
+        kWidgetsEnd,
+    };
 
-static Widget *window_player_page_widgets[] = {
-    window_player_overview_widgets,
-    window_player_statistics_widgets,
-};
+    static Widget *window_player_page_widgets[] = {
+        window_player_overview_widgets,
+        window_player_statistics_widgets,
+    };
+    // clang-format on
 
 #pragma endregion
 
-    // clang-format on
-
     class PlayerWindow final : public Window
     {
         int16_t _previousRotation = -1;
@@ -411,8 +412,6 @@ static Widget *window_player_page_widgets[] = {
                 viewport->pos = windowPos + ScreenCoordsXY{ viewportWidget->left, viewportWidget->top };
                 viewport->width = viewportWidget->width();
                 viewport->height = viewportWidget->height();
-                viewport->view_width = viewport->zoom.ApplyTo(viewport->width);
-                viewport->view_height = viewport->zoom.ApplyTo(viewport->height);
             }
 
             // Only enable kick button for other players
