@@ -9,10 +9,9 @@
 
 #pragma once
 
-#include "core/String.hpp"
+#include "core/StringTypes.h"
 
 #include <memory>
-#include <string>
 
 class Intent;
 struct ParkLoadResult;
