@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "common.h"
 #include "core/IStream.hpp"
 #include "ride/TrackDesign.h"
 
@@ -25,17 +24,17 @@ struct ITrackImporter
 public:
     virtual ~ITrackImporter() = default;
 
-    virtual bool Load(const utf8* path) abstract;
-    virtual bool LoadFromStream(OpenRCT2::IStream* stream) abstract;
+    virtual bool Load(const utf8* path) = 0;
+    virtual bool LoadFromStream(OpenRCT2::IStream* stream) = 0;
 
-    [[nodiscard]] virtual std::unique_ptr<TrackDesign> Import() abstract;
+    [[nodiscard]] virtual std::unique_ptr<TrackDesign> Import() = 0;
 };
 
-namespace TrackImporter
+namespace OpenRCT2::TrackImporter
 {
     [[nodiscard]] std::unique_ptr<ITrackImporter> Create(const std::string& hintPath);
     [[nodiscard]] std::unique_ptr<ITrackImporter> CreateTD4();
     [[nodiscard]] std::unique_ptr<ITrackImporter> CreateTD6();
 
     bool ExtensionIsRCT1(const std::string& extension);
-} // namespace TrackImporter
+} // namespace OpenRCT2::TrackImporter
