@@ -22,10 +22,10 @@
 #include "../world/Location.hpp"
 #include "../world/Park.h"
 #include "../world/QuarterTile.h"
-#include "../world/Surface.h"
-#include "../world/Wall.h"
 #include "../world/tile_element/EntranceElement.h"
+#include "../world/tile_element/PathElement.h"
 #include "../world/tile_element/Slope.h"
+#include "../world/tile_element/SurfaceElement.h"
 
 using namespace OpenRCT2;
 
