@@ -10,6 +10,7 @@
 #include "FootpathPlaceAction.h"
 
 #include "../Cheats.h"
+#include "../Context.h"
 #include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../OpenRCT2.h"
@@ -19,15 +20,19 @@
 #include "../management/Finance.h"
 #include "../object/PathAdditionEntry.h"
 #include "../ride/RideConstruction.h"
+#include "../windows/Intent.h"
 #include "../world/ConstructionClearance.h"
 #include "../world/Footpath.h"
 #include "../world/Location.hpp"
 #include "../world/Park.h"
+#include "../world/QuarterTile.h"
 #include "../world/Scenery.h"
-#include "../world/Surface.h"
 #include "../world/TileElementsView.h"
 #include "../world/Wall.h"
+#include "../world/tile_element/EntranceElement.h"
+#include "../world/tile_element/PathElement.h"
 #include "../world/tile_element/Slope.h"
+#include "../world/tile_element/SurfaceElement.h"
 
 #include <algorithm>
 
@@ -92,12 +97,12 @@ GameActions::Result FootpathPlaceAction::Query() const
         return GameActions::Result(GameActions::Status::Disallowed, STR_CANT_BUILD_FOOTPATH_HERE, STR_LAND_SLOPE_UNSUITABLE);
     }
 
-    if (_loc.z < FootpathMinHeight)
+    if (_loc.z < kFootpathMinHeight)
     {
         return GameActions::Result(GameActions::Status::Disallowed, STR_CANT_BUILD_FOOTPATH_HERE, STR_TOO_LOW);
     }
 
-    if (_loc.z > FootpathMaxHeight)
+    if (_loc.z > kFootpathMaxHeight)
     {
         return GameActions::Result(GameActions::Status::Disallowed, STR_CANT_BUILD_FOOTPATH_HERE, STR_TOO_HIGH);
     }
@@ -109,7 +114,9 @@ GameActions::Result FootpathPlaceAction::Query() const
             GameActions::Status::InvalidParameters, STR_CANT_BUILD_FOOTPATH_HERE, STR_ERR_VALUE_OUT_OF_RANGE);
     }
 
-    FootpathProvisionalRemove();
+    auto intent = Intent(INTENT_ACTION_REMOVE_PROVISIONAL_FOOTPATH);
+    ContextBroadcastIntent(&intent);
+
     auto tileElement = MapGetFootpathElementSlope(_loc, _slope);
     if (tileElement == nullptr)
     {
@@ -141,7 +148,7 @@ GameActions::Result FootpathPlaceAction::Execute() const
         {
             // It is possible, let's remove walls between the old and new piece of path
             auto zLow = _loc.z;
-            auto zHigh = zLow + PATH_CLEARANCE;
+            auto zHigh = zLow + kPathClearance;
             WallRemoveIntersectingWalls(
                 { _loc, zLow, zHigh + ((_slope & kTileSlopeRaisedCornersMask) ? 16 : 0) }, DirectionReverse(_direction));
             WallRemoveIntersectingWalls(
@@ -283,11 +290,11 @@ GameActions::Result FootpathPlaceAction::ElementInsertQuery(GameActions::Result
 
     QuarterTile quarterTile{ 0b1111, 0 };
     auto zLow = _loc.z;
-    auto zHigh = zLow + PATH_CLEARANCE;
+    auto zHigh = zLow + kPathClearance;
     if (_slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED)
     {
         quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope & kTileElementDirectionMask);
-        zHigh += PATH_HEIGHT_STEP;
+        zHigh += kPathHeightStep;
     }
 
     auto entranceElement = MapGetParkEntranceElementAt(_loc, false);
@@ -330,7 +337,7 @@ GameActions::Result FootpathPlaceAction::ElementInsertQuery(GameActions::Result
             GameActions::Status::InvalidParameters, STR_CANT_BUILD_FOOTPATH_HERE, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
     }
     int32_t supportHeight = zLow - surfaceElement->GetBaseZ();
-    res.Cost += supportHeight < 0 ? 20.00_GBP : (supportHeight / PATH_HEIGHT_STEP) * 5.00_GBP;
+    res.Cost += supportHeight < 0 ? 20.00_GBP : (supportHeight / kPathHeightStep) * 5.00_GBP;
 
     // Prevent the place sound from being spammed
     if (entranceIsSamePath)
@@ -352,11 +359,11 @@ GameActions::Result FootpathPlaceAction::ElementInsertExecute(GameActions::Resul
 
     QuarterTile quarterTile{ 0b1111, 0 };
     auto zLow = _loc.z;
-    auto zHigh = zLow + PATH_CLEARANCE;
+    auto zHigh = zLow + kPathClearance;
     if (_slope & FOOTPATH_PROPERTIES_FLAG_IS_SLOPED)
     {
         quarterTile = QuarterTile{ 0b1111, 0b1100 }.Rotate(_slope & kTileElementDirectionMask);
-        zHigh += PATH_HEIGHT_STEP;
+        zHigh += kPathHeightStep;
     }
 
     auto entranceElement = MapGetParkEntranceElementAt(_loc, false);
@@ -393,7 +400,7 @@ GameActions::Result FootpathPlaceAction::ElementInsertExecute(GameActions::Resul
             GameActions::Status::InvalidParameters, STR_CANT_BUILD_FOOTPATH_HERE, STR_ERR_SURFACE_ELEMENT_NOT_FOUND);
     }
     int32_t supportHeight = zLow - surfaceElement->GetBaseZ();
-    res.Cost += supportHeight < 0 ? 20.00_GBP : (supportHeight / PATH_HEIGHT_STEP) * 5.00_GBP;
+    res.Cost += supportHeight < 0 ? 20.00_GBP : (supportHeight / kPathHeightStep) * 5.00_GBP;
 
     if (entrancePath)
     {
