@@ -23,6 +23,9 @@
 #include "../world/ConstructionClearance.h"
 #include "../world/Footpath.h"
 #include "../world/Park.h"
+#include "../world/Wall.h"
+#include "../world/tile_element/SurfaceElement.h"
+#include "../world/tile_element/TrackElement.h"
 
 using namespace OpenRCT2;
 
@@ -97,7 +100,8 @@ GameActions::Result MazeSetTrackAction::Query() const
         res.ErrorMessage = STR_OFF_EDGE_OF_MAP;
         return res;
     }
-    if (!MapIsLocationOwned(_loc) && !OpenRCT2::GetGameState().Cheats.SandboxMode)
+    auto& gameState = GetGameState();
+    if (!MapIsLocationOwned(_loc) && !gameState.Cheats.SandboxMode)
     {
         res.Error = GameActions::Status::NotOwned;
         res.ErrorMessage = STR_LAND_NOT_OWNED_BY_PARK;
@@ -122,7 +126,7 @@ GameActions::Result MazeSetTrackAction::Query() const
     auto clearanceHeight = _loc.z + 32;
 
     auto heightDifference = baseHeight - surfaceElement->GetBaseZ();
-    if (heightDifference >= 0 && !OpenRCT2::GetGameState().Cheats.DisableSupportLimits)
+    if (heightDifference >= 0 && !gameState.Cheats.DisableSupportLimits)
     {
         heightDifference /= kCoordsZPerTinyZ;
 
