@@ -10,11 +10,10 @@
 #include "RideSetStatusAction.h"
 
 #include "../Cheats.h"
-#include "../common.h"
+#include "../Diagnostic.h"
 #include "../core/MemoryStream.h"
 #include "../interface/Window.h"
 #include "../localisation/Formatter.h"
-#include "../localisation/Localisation.h"
 #include "../localisation/StringIds.h"
 #include "../management/Finance.h"
 #include "../ride/Ride.h"
@@ -22,6 +21,8 @@
 #include "../ui/WindowManager.h"
 #include "../world/Park.h"
 
+using namespace OpenRCT2;
+
 static StringId _StatusErrorTitles[] = {
     STR_CANT_CLOSE,
     STR_CANT_OPEN,
