@@ -89,27 +89,21 @@ enum
 
 constexpr char NAC = '\0';
 
-#define ExampleTableEnd                                                                                                        \
-    {                                                                                                                          \
-        nullptr, nullptr                                                                                                       \
-    }
-#define OptionTableEnd                                                                                                         \
-    {                                                                                                                          \
-        UINT8_MAX, nullptr, NAC, nullptr, nullptr                                                                              \
-    }
-#define CommandTableEnd                                                                                                        \
-    {                                                                                                                          \
-        nullptr, nullptr, nullptr, nullptr, nullptr                                                                            \
-    }
+constexpr CommandLineExample kExampleTableEnd = CommandLineExample{ nullptr, nullptr };
+constexpr CommandLineOptionDefinition kOptionTableEnd = CommandLineOptionDefinition{ UINT8_MAX, nullptr, NAC, nullptr,
+                                                                                     nullptr };
+constexpr CommandLineCommand kCommandTableEnd = CommandLineCommand{ nullptr, nullptr, nullptr, nullptr, nullptr };
 
-#define DefineCommand(name, params, options, func)                                                                             \
-    {                                                                                                                          \
-        name, params, options, nullptr, func                                                                                   \
-    }
-#define DefineSubCommand(name, subcommandtable)                                                                                \
-    {                                                                                                                          \
-        name, "", nullptr, subcommandtable, nullptr                                                                            \
-    }
+consteval CommandLineCommand DefineCommand(
+    const char* name, const char* params, const CommandLineOptionDefinition* options, const CommandLineFunc func)
+{
+    return CommandLineCommand{ name, params, options, nullptr, func };
+}
+
+consteval CommandLineCommand DefineSubCommand(const char* name, const CommandLineCommand* subcommandtable)
+{
+    return CommandLineCommand{ name, "", nullptr, subcommandtable, nullptr };
+}
 
 namespace OpenRCT2::CommandLine
 {
