@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2023 OpenRCT2 developers
+ * Copyright (c) 2014-2024 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -9,8 +9,6 @@
 
 #pragma once
 
-#include "../common.h"
-
 #include <memory>
 
 enum class ADVERTISE_STATUS
@@ -26,8 +24,8 @@ struct INetworkServerAdvertiser
     {
     }
 
-    virtual ADVERTISE_STATUS GetStatus() const abstract;
-    virtual void Update() abstract;
+    virtual ADVERTISE_STATUS GetStatus() const = 0;
+    virtual void Update() = 0;
 };
 
 [[nodiscard]] std::unique_ptr<INetworkServerAdvertiser> CreateServerAdvertiser(uint16_t port);
