@@ -12,7 +12,7 @@
 #include "../../drawing/Drawing.h"
 #include "../../interface/Viewport.h"
 #include "../../util/Util.h"
-#include "../../world/Surface.h"
+#include "../../world/Footpath.h"
 #include "../../world/tile_element/Slope.h"
 #include "../Paint.SessionFlags.h"
 #include "../Paint.h"
