@@ -12,13 +12,13 @@
 #include "../../Game.h"
 #include "../../GameState.h"
 #include "../../config/Config.h"
+#include "../../core/CodepointView.hpp"
 #include "../../core/Numerics.hpp"
-#include "../../core/String.hpp"
 #include "../../core/UTF8.h"
 #include "../../interface/Viewport.h"
 #include "../../localisation/Formatting.h"
 #include "../../localisation/StringIds.h"
-#include "../../object/LargeSceneryObject.h"
+#include "../../object/LargeSceneryEntry.h"
 #include "../../profiling/Profiling.h"
 #include "../../ride/Ride.h"
 #include "../../ride/TrackDesign.h"
@@ -27,6 +27,7 @@
 #include "../../world/Map.h"
 #include "../../world/Scenery.h"
 #include "../../world/TileInspector.h"
+#include "../../world/tile_element/LargeSceneryElement.h"
 #include "../Boundbox.h"
 #include "../support/WoodenSupports.h"
 #include "Paint.TileElement.h"
@@ -62,7 +63,7 @@ static void PaintLargeScenerySupports(
 {
     PROFILED_FUNCTION();
 
-    if (tile.flags & LARGE_SCENERY_TILE_FLAG_NO_SUPPORTS)
+    if (!tile.hasSupports)
         return;
 
     auto transitionType = WoodenSupportTransitionType::None;
@@ -77,7 +78,7 @@ static void PaintLargeScenerySupports(
         session, WoodenSupportType::Truss, WoodenSupportSubType::NeSw, direction, supportHeight, imageTemplate, transitionType);
 
     int32_t clearanceHeight = Ceil2(tileElement.GetClearanceZ() + 15, 16);
-    if (tile.flags & LARGE_SCENERY_TILE_FLAG_ALLOW_SUPPORTS_ABOVE)
+    if (tile.allowSupportsAbove)
     {
         PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, clearanceHeight, 0x20);
     }
@@ -191,7 +192,7 @@ static void PaintLargeScenery3DText(
 {
     PROFILED_FUNCTION();
 
-    if (sceneryEntry.tiles[1].x_offset != -1)
+    if (sceneryEntry.tiles.size() != 1)
     {
         auto sequenceDirection = (tileElement.GetSequenceIndex() - 1) & 3;
         if (sequenceDirection != direction)
@@ -340,18 +341,16 @@ void PaintLargeScenery(PaintSession& session, uint8_t direction, uint16_t height
         return;
 
     auto sequenceNum = tileElement.GetSequenceIndex();
-    const auto* object = tileElement.GetObject();
-    if (object == nullptr)
-        return;
 
     const auto* sceneryEntry = tileElement.GetEntry();
     if (sceneryEntry == nullptr)
         return;
 
-    const auto* tile = object->GetTileForSequence(sequenceNum);
-    if (tile == nullptr)
+    if (sequenceNum >= sceneryEntry->tiles.size())
         return;
 
+    auto& tile = sceneryEntry->tiles[sequenceNum];
+
     session.InteractionType = ViewportInteractionItem::LargeScenery;
 
     auto isGhost = false;
@@ -388,14 +387,16 @@ void PaintLargeScenery(PaintSession& session, uint8_t direction, uint16_t height
         }
     }
 
-    auto boxlengthZ = std::min<uint8_t>(tile->z_clearance, 128) - 3;
-    auto flags = tile->flags;
+    auto boxlengthZ = std::min(tile.zClearance, 128) - 3;
     auto bbIndex = 16;
-    if (flags & 0xF00)
+    // This matches vanilla but its odd that its a branch on walls
+    // and then operates on corners. I guess its because if you
+    // have no walls then you must be occupying the whole tile
+    // and all the connecting tiles so using an even bigger boundbox
+    // makes sense.
+    if (tile.walls)
     {
-        flags &= 0xF000;
-        flags = Numerics::rol16(flags, direction);
-        bbIndex = (flags & 0xF) | (flags >> 12);
+        bbIndex = Numerics::rol4(tile.corners, direction);
     }
     const CoordsXYZ& bbOffset = { LargeSceneryBoundBoxes[bbIndex].offset, height };
     const CoordsXYZ& bbLength = { LargeSceneryBoundBoxes[bbIndex].length, boxlengthZ };
@@ -407,7 +408,7 @@ void PaintLargeScenery(PaintSession& session, uint8_t direction, uint16_t height
     {
         if (sceneryEntry->flags & LARGE_SCENERY_FLAG_3D_TEXT)
         {
-            PaintLargeScenery3DText(session, *sceneryEntry, *tile, tileElement, direction, height, isGhost);
+            PaintLargeScenery3DText(session, *sceneryEntry, tile, tileElement, direction, height, isGhost);
         }
         else if (session.DPI.zoom_level <= ZoomLevel{ 0 })
         {
@@ -419,5 +420,5 @@ void PaintLargeScenery(PaintSession& session, uint8_t direction, uint16_t height
         }
     }
     PaintLargeScenerySupports(
-        session, direction, height, tileElement, isGhost ? imageTemplate : ImageId(0, COLOUR_BLACK), *tile);
+        session, direction, height, tileElement, isGhost ? imageTemplate : ImageId(0, COLOUR_BLACK), tile);
 }
