@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../ride/TrackDesign.h"
 
 #include <vector>
@@ -19,7 +18,7 @@ namespace OpenRCT2
     struct IStream;
 }
 
-namespace RCT2
+namespace OpenRCT2::RCT2
 {
     /**
      * Class to export RollerCoaster Tycoon 2 track designs (*.TD6).
@@ -35,4 +34,4 @@ namespace RCT2
     private:
         const TrackDesign& _trackDesign;
     };
-} // namespace RCT2
+} // namespace OpenRCT2::RCT2
