@@ -37,6 +37,7 @@ enum : StringId
     STR_RIDE_NAME_JUNIOR_ROLLER_COASTER = 6,
     STR_RIDE_NAME_LAY_DOWN_ROLLER_COASTER = 64,
     STR_RIDE_NAME_LIM_LAUNCHED_ROLLER_COASTER = 92,
+    STR_RIDE_NAME_LSM_LAUNCHED_ROLLER_COASTER = 98,
     STR_RIDE_NAME_LOOPING_ROLLER_COASTER = 17,
     STR_RIDE_NAME_MINE_RIDE = 90,
     STR_RIDE_NAME_MINE_TRAIN_COASTER = 19,
@@ -79,6 +80,7 @@ enum : StringId
     STR_RIDE_DESCRIPTION_JUNIOR_ROLLER_COASTER = 516,
     STR_RIDE_DESCRIPTION_LAY_DOWN_ROLLER_COASTER = 574,
     STR_RIDE_DESCRIPTION_LIM_LAUNCHED_ROLLER_COASTER = 602,
+    STR_RIDE_DESCRIPTION_LSM_LAUNCHED_ROLLER_COASTER = 608,
     STR_RIDE_DESCRIPTION_LOOPING_ROLLER_COASTER = 527,
     STR_RIDE_DESCRIPTION_MINE_RIDE = 600,
     STR_RIDE_DESCRIPTION_MINE_TRAIN_COASTER = 529,
@@ -205,4 +207,10 @@ enum : StringId
     STR_RIDE_DESCRIPTION_RIVER_RAPIDS = 536,
     STR_RIDE_DESCRIPTION_SPLASH_BOATS = 572,
     STR_RIDE_DESCRIPTION_SUBMARINE_RIDE = 590,
+
+    // Other strings, used in RTDs
+    STR_RIDE_CONSTRUCTION_O_SHAPED_ENCLOSED_TRACK_TIP = 1461,
+    STR_RIDE_CONSTRUCTION_STANDARD_RC_TRACK_TIP = 3062,
+    STR_RIDE_CONSTRUCTION_U_SHAPED_OPEN_TRACK_TIP = 1460,
+    STR_RIDE_CONSTRUCTION_WATER_CHANNEL_TIP = 3063,
 };
