@@ -34,7 +34,9 @@
 #include "../core/DataSerialiser.h"
 #include "../core/File.h"
 #include "../core/Numerics.hpp"
+#include "../core/SawyerCoding.h"
 #include "../core/String.hpp"
+#include "../core/UnitConversion.h"
 #include "../drawing/X8DrawingEngine.h"
 #include "../interface/Viewport.h"
 #include "../localisation/StringIds.h"
@@ -51,14 +53,15 @@
 #include "../object/StationObject.h"
 #include "../rct2/RCT2.h"
 #include "../ride/RideConstruction.h"
-#include "../util/SawyerCoding.h"
 #include "../util/Util.h"
 #include "../world/Footpath.h"
 #include "../world/Park.h"
 #include "../world/Scenery.h"
-#include "../world/Surface.h"
-#include "../world/Wall.h"
+#include "../world/tile_element/EntranceElement.h"
+#include "../world/tile_element/PathElement.h"
 #include "../world/tile_element/Slope.h"
+#include "../world/tile_element/SurfaceElement.h"
+#include "../world/tile_element/TrackElement.h"
 #include "Ride.h"
 #include "RideData.h"
 #include "Track.h"
@@ -150,7 +153,7 @@ ResultWithMessage TrackDesign::CreateTrackDesign(TrackDesignState& tds, const Ri
     appearance.stationObjectIdentifier = TrackDesignGetStationObjectIdentifier(ride);
     statistics.maxSpeed = static_cast<int8_t>(ride.max_speed / 65536);
     statistics.averageSpeed = static_cast<int8_t>(ride.average_speed / 65536);
-    statistics.rideLength = ride.GetTotalLength() / 65536;
+    statistics.rideLength = ToHumanReadableRideLength(ride.GetTotalLength());
     statistics.maxPositiveVerticalG = ride.max_positive_vertical_g;
     statistics.maxNegativeVerticalG = ride.max_negative_vertical_g;
     statistics.maxLateralG = ride.max_lateral_g;
@@ -203,14 +206,13 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
     z = newCoords->z;
 
     const auto& ted = GetTrackElementDescriptor(trackElement.element->AsTrack()->GetTrackType());
-    const TrackCoordinates* trackCoordinates = &ted.Coordinates;
-    const auto* trackBlock = ted.Block;
+    const TrackCoordinates* trackCoordinates = &ted.coordinates;
     // Used in the following loop to know when we have
     // completed all of the elements and are back at the
     // start.
     TileElement* initialMap = trackElement.element;
 
-    CoordsXYZ startPos = { trackElement.x, trackElement.y, z + trackCoordinates->z_begin - trackBlock->z };
+    CoordsXYZ startPos = { trackElement.x, trackElement.y, z + trackCoordinates->zBegin - ted.sequences[0].clearance.z };
     tds.origin = startPos;
 
     do
@@ -239,7 +241,7 @@ ResultWithMessage TrackDesign::CreateTrackDesignTrack(TrackDesignState& tds, con
         if (element->HasChain())
             track.SetFlag(TrackDesignTrackElementFlag::hasChain);
 
-        if (ride.GetRideTypeDescriptor().HasFlag(RIDE_TYPE_FLAG_HAS_ALTERNATIVE_TRACK_TYPE) && element->IsInverted())
+        if (ride.GetRideTypeDescriptor().HasFlag(RtdFlag::hasInvertedVariant) && element->IsInverted())
         {
             track.SetFlag(TrackDesignTrackElementFlag::isInverted);
         }
@@ -642,7 +644,7 @@ struct TrackSceneryEntry
 
 static ObjectEntryIndex TrackDesignGetDefaultSurfaceIndex(bool isQueue)
 {
-    for (ObjectEntryIndex i = 0; i < MAX_FOOTPATH_SURFACE_OBJECTS; i++)
+    for (ObjectEntryIndex i = 0; i < kMaxFootpathSurfaceObjects; i++)
     {
         auto footpathSurfaceObj = GetPathSurfaceEntry(i);
         if (footpathSurfaceObj != nullptr)
@@ -665,7 +667,7 @@ static ObjectEntryIndex TrackDesignGetDefaultSurfaceIndex(bool isQueue)
 
 static ObjectEntryIndex TrackDesignGetDefaultRailingIndex()
 {
-    for (ObjectEntryIndex i = 0; i < MAX_FOOTPATH_RAILINGS_OBJECTS; i++)
+    for (ObjectEntryIndex i = 0; i < kMaxFootpathRailingsObjects; i++)
     {
         auto footpathRailingsObj = GetPathRailingsEntry(i);
         if (footpathRailingsObj != nullptr)
@@ -759,23 +761,23 @@ static void TrackDesignMirrorScenery(TrackDesign& td)
             {
                 auto* sceneryEntry = reinterpret_cast<const LargeSceneryEntry*>(obj->GetLegacyData());
                 int16_t x1 = 0, x2 = 0, y1 = 0, y2 = 0;
-                for (LargeSceneryTile* tile = sceneryEntry->tiles; tile->x_offset != -1; tile++)
+                for (auto& tile : sceneryEntry->tiles)
                 {
-                    if (x1 > tile->x_offset)
+                    if (x1 > tile.offset.x)
                     {
-                        x1 = tile->x_offset;
+                        x1 = tile.offset.x;
                     }
-                    if (x2 < tile->x_offset)
+                    if (x2 < tile.offset.x)
                     {
-                        x2 = tile->x_offset;
+                        x2 = tile.offset.x;
                     }
-                    if (y1 > tile->y_offset)
+                    if (y1 > tile.offset.y)
                     {
-                        y1 = tile->y_offset;
+                        y1 = tile.offset.y;
                     }
-                    if (y2 < tile->y_offset)
+                    if (y2 < tile.offset.y)
                     {
-                        y2 = tile->y_offset;
+                        y2 = tile.offset.y;
                     }
                 }
 
@@ -866,7 +868,7 @@ static void TrackDesignMirrorRide(TrackDesign& td)
     for (auto& track : td.trackElements)
     {
         const auto& ted = GetTrackElementDescriptor(track.type);
-        track.type = ted.MirrorElement;
+        track.type = ted.mirrorElement;
     }
 }
 
@@ -887,7 +889,8 @@ static void TrackDesignMirrorMaze(TrackDesign& td)
 
         uint32_t mazeEntry = maze.mazeEntry;
         uint16_t newEntry = 0;
-        for (uint8_t position = UtilBitScanForward(mazeEntry); position != 0xFF; position = UtilBitScanForward(mazeEntry))
+        for (uint8_t position = Numerics::bitScanForward(mazeEntry); position != 0xFF;
+             position = Numerics::bitScanForward(mazeEntry))
         {
             mazeEntry &= ~(1 << position);
             newEntry |= (1 << maze_segment_mirror_map[position]);
@@ -903,7 +906,7 @@ static void TrackDesignMirrorMaze(TrackDesign& td)
 void TrackDesignMirror(TrackDesign& td)
 {
     const auto& rtd = GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex);
-    if (rtd.HasFlag(RIDE_TYPE_FLAG_IS_MAZE))
+    if (rtd.HasFlag(RtdFlag::isMaze))
     {
         TrackDesignMirrorMaze(td);
     }
@@ -1565,18 +1568,18 @@ static GameActions::Result TrackDesignPlaceRide(
         switch (tds.placeOperation)
         {
             case TrackPlaceOperation::drawOutlines:
-                for (const PreviewTrack* trackBlock = ted.Block; trackBlock->index != 0xFF; trackBlock++)
+                for (uint8_t i = 0; i < ted.numSequences; i++)
                 {
-                    auto tile = CoordsXY{ newCoords } + CoordsXY{ trackBlock->x, trackBlock->y }.Rotate(rotation);
+                    const auto& trackBlock = ted.sequences[i].clearance;
+                    auto tile = CoordsXY{ newCoords } + CoordsXY{ trackBlock.x, trackBlock.y }.Rotate(rotation);
                     TrackDesignUpdatePreviewBounds(tds, { tile, newCoords.z });
                     TrackDesignAddSelectedTile(tile);
                 }
                 break;
             case TrackPlaceOperation::removeGhost:
             {
-                const TrackCoordinates* trackCoordinates = &ted.Coordinates;
-                const PreviewTrack* trackBlock = ted.Block;
-                int32_t tempZ = newCoords.z - trackCoordinates->z_begin + trackBlock->z;
+                const TrackCoordinates* trackCoordinates = &ted.coordinates;
+                int32_t tempZ = newCoords.z - trackCoordinates->zBegin + ted.sequences[0].clearance.z;
                 auto trackRemoveAction = TrackRemoveAction(
                     trackType, 0, { newCoords, tempZ, static_cast<Direction>(rotation & 3) });
                 trackRemoveAction.SetFlags(
@@ -1590,19 +1593,19 @@ static GameActions::Result TrackDesignPlaceRide(
             case TrackPlaceOperation::placeGhost:
             case TrackPlaceOperation::placeTrackPreview:
             {
-                const TrackCoordinates* trackCoordinates = &ted.Coordinates;
+                const TrackCoordinates* trackCoordinates = &ted.coordinates;
 
                 // di
-                int16_t tempZ = newCoords.z - trackCoordinates->z_begin;
+                int16_t tempZ = newCoords.z - trackCoordinates->zBegin;
 
-                int32_t liftHillAndAlternativeState = 0;
+                SelectedLiftAndInverted liftHillAndAlternativeState{};
                 if (track.HasFlag(TrackDesignTrackElementFlag::hasChain))
                 {
-                    liftHillAndAlternativeState |= 1;
+                    liftHillAndAlternativeState.set(LiftHillAndInverted::liftHill);
                 }
                 if (track.HasFlag(TrackDesignTrackElementFlag::isInverted))
                 {
-                    liftHillAndAlternativeState |= 2;
+                    liftHillAndAlternativeState.set(LiftHillAndInverted::inverted);
                 }
 
                 uint8_t flags = GAME_COMMAND_FLAG_APPLY;
@@ -1643,10 +1646,11 @@ static GameActions::Result TrackDesignPlaceRide(
             }
             case TrackPlaceOperation::getPlaceZ:
             {
-                int32_t tempZ = newCoords.z - ted.Coordinates.z_begin;
-                for (const PreviewTrack* trackBlock = ted.Block; trackBlock->index != 0xFF; trackBlock++)
+                int32_t tempZ = newCoords.z - ted.coordinates.zBegin;
+                for (uint8_t i = 0; i < ted.numSequences; i++)
                 {
-                    auto tile = CoordsXY{ newCoords } + CoordsXY{ trackBlock->x, trackBlock->y }.Rotate(rotation);
+                    const auto& trackBlock = ted.sequences[i].clearance;
+                    auto tile = CoordsXY{ newCoords } + CoordsXY{ trackBlock.x, trackBlock.y }.Rotate(rotation);
                     if (!MapIsLocationValid(tile))
                     {
                         continue;
@@ -1675,7 +1679,7 @@ static GameActions::Result TrackDesignPlaceRide(
                     {
                         surfaceZ = waterZ;
                     }
-                    int32_t heightDifference = tempZ + tds.placeZ + trackBlock->z - surfaceZ;
+                    int32_t heightDifference = tempZ + tds.placeZ + trackBlock.z - surfaceZ;
                     if (heightDifference < 0)
                     {
                         tds.placeZ -= heightDifference;
@@ -1685,13 +1689,13 @@ static GameActions::Result TrackDesignPlaceRide(
             }
         }
 
-        const TrackCoordinates& track_coordinates = ted.Coordinates;
+        const TrackCoordinates& track_coordinates = ted.coordinates;
         auto offsetAndRotatedTrack = CoordsXY{ newCoords }
             + CoordsXY{ track_coordinates.x, track_coordinates.y }.Rotate(rotation);
 
-        newCoords = { offsetAndRotatedTrack, newCoords.z - track_coordinates.z_begin + track_coordinates.z_end };
-        rotation = (rotation + track_coordinates.rotation_end - track_coordinates.rotation_begin) & 3;
-        if (track_coordinates.rotation_end & (1 << 2))
+        newCoords = { offsetAndRotatedTrack, newCoords.z - track_coordinates.zBegin + track_coordinates.zEnd };
+        rotation = (rotation + track_coordinates.rotationEnd - track_coordinates.rotationBegin) & 3;
+        if (track_coordinates.rotationEnd & (1 << 2))
         {
             rotation |= (1 << 2);
         }
@@ -1763,7 +1767,7 @@ static GameActions::Result TrackDesignPlaceVirtual(
 
     GameActions::Result trackPlaceRes;
     const auto& rtd = GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex);
-    if (rtd.HasFlag(RIDE_TYPE_FLAG_IS_MAZE))
+    if (rtd.HasFlag(RtdFlag::isMaze))
     {
         trackPlaceRes = TrackDesignPlaceMaze(tds, td, coords, ride);
     }
@@ -1903,7 +1907,7 @@ static bool TrackDesignPlacePreview(
 
     // Flat rides need their vehicle colours loaded for display
     // in the preview window
-    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RIDE_TYPE_FLAG_HAS_TRACK))
+    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RtdFlag::hasTrack))
     {
         for (size_t i = 0; i < std::size(ride->vehicle_colours); i++)
         {
@@ -2084,7 +2088,7 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels)
 
     // Special case for flat rides - Z-axis info is irrelevant
     // and must be zeroed out lest the preview be off-centre
-    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RIDE_TYPE_FLAG_HAS_TRACK))
+    if (!GetRideTypeDescriptor(td.trackAndVehicle.rtdIndex).HasFlag(RtdFlag::hasTrack))
     {
         centre.z = 0;
         size_z = 0;
@@ -2112,14 +2116,11 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels)
     Viewport view;
     view.width = 370;
     view.height = 217;
-    view.view_width = size_x;
-    view.view_height = size_y;
     view.pos = { 0, 0 };
     view.zoom = zoom_level;
     view.flags = VIEWPORT_FLAG_HIDE_BASE | VIEWPORT_FLAG_HIDE_ENTITIES;
 
     DrawPixelInfo dpi;
-    dpi.zoom_level = zoom_level;
     dpi.x = 0;
     dpi.y = 0;
     dpi.width = 370;
@@ -2135,7 +2136,7 @@ void TrackDesignDrawPreview(TrackDesign& td, uint8_t* pixels)
     {
         view.viewPos = Translate3DTo2DWithZ(i, centre) - offset;
         view.rotation = i;
-        ViewportRender(dpi, &view, { {}, ScreenCoordsXY{ size_x, size_y } });
+        ViewportRender(dpi, &view);
 
         dpi.bits += kTrackPreviewImageSize;
     }
@@ -2152,7 +2153,8 @@ static void TrackDesignPreviewClearMap()
 {
     auto numTiles = kMaximumMapSizeTechnical * kMaximumMapSizeTechnical;
 
-    GetGameState().MapSize = TRACK_DESIGN_PREVIEW_MAP_SIZE;
+    auto& gameState = GetGameState();
+    gameState.MapSize = TRACK_DESIGN_PREVIEW_MAP_SIZE;
 
     // Reserve ~8 elements per tile
     std::vector<TileElement> tileElements;
@@ -2171,7 +2173,8 @@ static void TrackDesignPreviewClearMap()
         element->AsSurface()->SetOwnership(OWNERSHIP_OWNED);
         element->AsSurface()->SetParkFences(0);
     }
-    SetTileElements(std::move(tileElements));
+
+    SetTileElements(gameState, std::move(tileElements));
 }
 
 bool TrackDesignAreEntranceAndExitPlaced()
