@@ -89,15 +89,16 @@ namespace OpenRCT2::Scripting
             constexpr char delimiter = ',';
             size_t start_pos = 0;
             size_t end_pos = 0;
-            while ((end_pos = gConfigPlugin.AllowedHosts.find(delimiter, start_pos)) != std::string::npos)
+            while ((end_pos = Config::Get().plugin.AllowedHosts.find(delimiter, start_pos)) != std::string::npos)
             {
-                if (host == gConfigPlugin.AllowedHosts.substr(start_pos, end_pos - start_pos))
+                if (host == Config::Get().plugin.AllowedHosts.substr(start_pos, end_pos - start_pos))
                 {
                     return true;
                 }
                 start_pos = end_pos + 1;
             }
-            return host == gConfigPlugin.AllowedHosts.substr(start_pos, gConfigPlugin.AllowedHosts.length() - start_pos);
+            return host
+                == Config::Get().plugin.AllowedHosts.substr(start_pos, Config::Get().plugin.AllowedHosts.length() - start_pos);
         }
 
     public:
@@ -343,7 +344,7 @@ namespace OpenRCT2::Scripting
                 }
                 else if (status == SocketStatus::Connected)
                 {
-                    char buffer[2048];
+                    char buffer[16384];
                     size_t bytesRead{};
                     auto result = _socket->ReceiveData(buffer, sizeof(buffer), &bytesRead);
                     switch (result)
