@@ -15,8 +15,7 @@
 #    include "../../../Date.h"
 #    include "../../../Game.h"
 #    include "../../../GameState.h"
-#    include "../../../common.h"
-#    include "../../../localisation/Date.h"
+#    include "../../../localisation/Localisation.Date.h"
 #    include "../../Duktape.hpp"
 #    include "../../ScriptEngine.h"
 
